#!/bin/bash
#%stage: block
#%depends: dm
#%provides: dmroot
#%programs: dmraid
#%programs: mkdir
#%if: -n "$root_dmraid"
#
##### Device Mapper Raid
##
## If the root device uses a software raid based on device mapper, 
## this initializes and waits for the device to appear.
##
## Command line parameters
## -----------------------
##
## root_dmraid=1	use device mapper raid
## 

[ -d /run/lock ] || mkdir -p /run/lock >/dev/null 2>&1
dmraid -a y -p
wait_for_events

